@@ -39,6 +39,7 @@ from calculate.lib.utils.files import (isMount, removeDir,
 from calculate.lib.utils.device import (detectDeviceForPartition,
                                         getUdevDeviceInfo, countPartitions)
 from calculate.lib.utils.tools import classproperty, Signal, traverse
+from calculate.lib.utils.text import _u8
 from calculate.lib.variables.linux import LinuxDataVars, Linux
 
 from calculate.lib.cl_lang import setLocalTranslate, _
@@ -715,10 +716,10 @@ class DirectoryDistributive(Distributive):
     @classmethod
     @Distributive.required("directory", "system_mounted")
     def unserialize(cls, data, parent=None):
-        ld = DirectoryDistributive(data['directory'], parent=parent)
-        ld.system_mounted = data['system_mounted']
+        ld = DirectoryDistributive(_u8(data['directory']), parent=parent)
+        ld.system_mounted = _u8(data['system_mounted'])
         if "mdirectory" in data:
-            ld.mdirectory = data['mdirectory']
+            ld.mdirectory = _u8(data['mdirectory'])
         ld.childs = [Distributive.unserialize(x, parent=ld) for x in
                      data.get('childs', [])]
         return ld
@@ -746,7 +747,8 @@ class MultiPartitions:
                                   x.update({y: getattr(DataPartition, y)}) or x,
                               filter(lambda x: not x.startswith('_'),
                                      DataPartition.__dict__), {})
-        updateAttrData = filter(lambda x: x[1] is not None, dictDataPart.items())
+        updateAttrData = filter(lambda x: x[1] is not None,
+                                dictDataPart.items())
         defaultAttr = []
         for attrName, attrValue in updateAttrData:
             if not attrName in argv.keys():
@@ -797,6 +799,7 @@ class MultiPartitions:
         """Get list mount point ["/boot",...]"""
         return map(lambda x: x.mountPoint, self.listPartitions)
 
+
 class FormatProcess(process):
     format_util = ""
     dos_id = "0"
@@ -826,6 +829,7 @@ class FormatProcess(process):
     def label(self):
         return ()
 
+
 class FormatProcessGeneric(FormatProcess):
     dos_id = "83"
     gpt_id = "8300"
@@ -836,21 +840,26 @@ class FormatProcessGeneric(FormatProcess):
     def param(self):
         return self.get_label(), self.dev
 
+
 class FormatExt2(FormatProcessGeneric):
     format_util = "/sbin/mkfs.ext2"
 
+
 class FormatExt3(FormatExt2):
     format_util = "/sbin/mkfs.ext3"
 
+
 class FormatExt4(FormatExt2):
     format_util = "/sbin/mkfs.ext4"
 
+
 class FormatJfs(FormatProcessGeneric):
     format_util = "/sbin/mkfs.jfs"
 
     def param(self):
         return self.get_label(), "-f", self.dev
 
+
 class FormatReiserfs(FormatProcessGeneric):
     format_util = "/sbin/mkfs.reiserfs"
 
@@ -860,15 +869,18 @@ class FormatReiserfs(FormatProcessGeneric):
     def label(self):
         return "-l", self._label
 
+
 class FormatNilfs2(FormatProcessGeneric):
     format_util = "/sbin/mkfs.nilfs2"
 
+
 class FormatXfs(FormatProcessGeneric):
     format_util = "/sbin/mkfs.xfs"
 
     def param(self):
         return self.get_label(), "-f", self.dev
 
+
 class FormatVfat(FormatProcess):
     dos_id = "0b"
     gpt_id = "0700"
@@ -880,6 +892,7 @@ class FormatVfat(FormatProcess):
     def label(self):
         return "-n", self._label
 
+
 class FormatNtfs(FormatProcessGeneric):
     dos_id = "07"
     gpt_id = "0700"
@@ -888,6 +901,7 @@ class FormatNtfs(FormatProcessGeneric):
     def param(self):
         return self.get_label(), "-FQ", self.dev
 
+
 class FormatUefi(FormatVfat):
     dos_id = "ef"
     gpt_id = "EF00"
@@ -895,6 +909,7 @@ class FormatUefi(FormatVfat):
     def label(self):
         return ()
 
+
 class FormatSwap(FormatProcess):
     dos_id = "82"
     gpt_id = "8200"
@@ -903,12 +918,14 @@ class FormatSwap(FormatProcess):
     def param(self):
         return self.dev,
 
+
 class FormatBtrfs(FormatProcessGeneric):
     format_util = "/sbin/mkfs.btrfs"
 
     def param(self):
         return "-f", self.get_label(), self.dev
 
+
 class PartitionDistributive(Distributive):
     format_map = {
         'ext2': FormatExt2,
@@ -1203,9 +1220,9 @@ class PartitionDistributive(Distributive):
     @classmethod
     @Distributive.required("partition", "mdirectory", "flag_remove_directory")
     def unserialize(cls, data, parent=None):
-        ld = PartitionDistributive(data['partition'], parent=parent)
-        ld.mdirectory = data['mdirectory']
-        ld.flagRemoveDir = data['flag_remove_directory']
+        ld = PartitionDistributive(_u8(data['partition']), parent=parent)
+        ld.mdirectory = _u8(data['mdirectory'])
+        ld.flagRemoveDir = _u8(data['flag_remove_directory'])
         ld.childs = [Distributive.unserialize(x, parent=ld) for x in
                      data.get('childs', [])]
         return ld
@@ -1333,8 +1350,9 @@ class ArchiveDistributive(Distributive):
     @classmethod
     @Distributive.required("mdirectory", "file")
     def unserialize(cls, data, parent=None):
-        ld = ArchiveDistributive(data['file'],
-                                 mdirectory=data['mdirectory'], parent=parent)
+        ld = ArchiveDistributive(_u8(data['file']),
+                                 mdirectory=_u8(data['mdirectory']),
+                                 parent=parent)
         ld.childs = [Distributive.unserialize(x, parent=ld)
                      for x in data.get('childs', [])]
         return ld
@@ -1421,8 +1439,9 @@ class SquashDistributive(Distributive):
     @classmethod
     @Distributive.required("mdirectory", "file")
     def unserialize(cls, data, parent=None):
-        ld = SquashDistributive(data['file'],
-                                mdirectory=data['mdirectory'], parent=parent)
+        ld = SquashDistributive(_u8(data['file']),
+                                mdirectory=_u8(data['mdirectory']),
+                                parent=parent)
         ld.childs = [Distributive.unserialize(x, parent=ld)
                      for x in data.get('childs', [])]
         return ld
@@ -1633,9 +1652,9 @@ class IsoDistributive(Distributive):
     @classmethod
     @Distributive.required("mdirectory", "bdirectory", "file")
     def unserialize(cls, data, parent=None):
-        ld = IsoDistributive(data['file'],
-                             mdirectory=data['mdirectory'],
-                             bdirectory=data['bdirectory'],
+        ld = IsoDistributive(_u8(data['file']),
+                             mdirectory=_u8(data['mdirectory']),
+                             bdirectory=_u8(data['bdirectory']),
                              parent=parent)
         ld.childs = [Distributive.unserialize(x, parent=ld)
                      for x in data.get('childs', [])]
@@ -1818,9 +1837,9 @@ class LayeredDistributive(Distributive):
     @classmethod
     @Distributive.required("mdirectory", "diff_directory", "image_file")
     def unserialize(cls, data, parent=None):
-        ld = LayeredDistributive(data['mdirectory'],
-                                 data['diff_directory'],
-                                 data['image_file'],
+        ld = LayeredDistributive(_u8(data['mdirectory']),
+                                 _u8(data['diff_directory']),
+                                 _u8(data['image_file']),
                                  parent=parent)
         ld.childs = [Distributive.unserialize(x, parent=ld)
                      for x in data.get('childs', [])]
